pub struct ClusterVolumeSpecAccessModeInlineItemSecretsInlineItem {
pub key: Option<String>,
pub secret: Option<String>,
}Expand description
One cluster volume secret entry. Defines a key-value pair that is passed to the plugin.
Fields
key: Option<String>Key is the name of the key of the key-value pair passed to the plugin.
secret: Option<String>Secret is the swarm Secret object from which to read data. This can be a Secret name or ID. The Secret data is retrieved by swarm and used as the value of the key-value pair passed to the plugin.