pub struct SwarmSpecTaskDefaultsInlineItemLogDriverInlineItem {
pub name: Option<String>,
pub options: Option<HashMap<String, String>>,
}Expand description
The log driver to use for tasks created in the orchestrator if unspecified by a service.
Updating this value only affects new tasks. Existing tasks continue to use their previously configured log driver until recreated.
Fields
name: Option<String>The log driver to use as a default for new tasks.
options: Option<HashMap<String, String>>Driver-specific options for the selectd log driver, specified as key/value pairs.